Module sync

Module sync 

Structs

SnapshotInfo
Metadata for a state snapshot.

Enums

ChunkApplyResult
Result of applying a snapshot chunk.
SnapshotOfferResult
Result of offering a snapshot to the application.
SyncRequest
Sync request sent by a node that needs to catch up
SyncResponse
Sync response from a node serving blocks

Constants

MAX_SYNC_BATCH
Maximum number of blocks in a single sync response