Module sync
hotmint_
types
0.5.0
Module sync
Module Items
Enums
Constants
In crate hotmint_
types
hotmint_types
Module
sync
Enums

Sync
Request
Sync request sent by a node that needs to catch up
Sync
Response
Sync response from a node serving blocks
Constants

MAX_
SYNC_
BATCH
Maximum number of blocks in a single sync response