Module sync

Module sync 

Enums

SyncRequest
Sync request sent by a node that needs to catch up
SyncResponse
Sync response from a node serving blocks

Constants

MAX_SYNC_BATCH
Maximum number of blocks in a single sync response